import requests

class HttpMethod:
    def __init__(self):
        raise AttributeError

    @staticmethod
    def get(func):
        def decorator(*args, **kwargs):
            param = func(*args, **kwargs)
            resp = requests.get(url=param.url, headers=param.headers, params=param.data)
            return resp.json()
        return decorator

    @staticmethod
    def post(func):
        def decorator(*args, **kwargs):
            param = func(*args, **kwargs)
            resp = requests.post(url=param.url, headers=param.headers, data=param.data)
            return resp.json()
        return decorator


class HttpParam:
    def __init__(self, url, headers=None, data=None):
        self.url = url
        self.headers = headers
        self.data = data


# -*- coding: utf-8 -*-
from distutils.core import setup

setup(
    name='vericoin',
    version='0.1.8',
    packages=['vericoin', 'vericoin/core'],
    install_requires=['pandas', 'ratelimit'],
    url='https://github.com/sharebook-kr/vericoin',
    author='jonghun.yoo',
    author_email='jonghun.yoo@outlook.com',
    description='암호화폐 Daily 가격 조회',
)